"use strict";
exports.__esModule = true;
exports.toJestConfig = void 0;
var compose_1 = require("../utils/compose");
var given_1 = require("../utils/given");
var not_1 = require("../utils/not");
var objects_1 = require("../utils/objects");
var strings_1 = require("../utils/strings");
/**
 * Appends start/end RegExp characters (^/$) at the beginning/end
 * of each module name. Makes otherwise loose string matches exact.
 */
var normalizeExactMatch = function (config, _a) {
    var moduleName = _a[0], modulePath = _a[1];
    var transformedModuleName = compose_1.compose(given_1.given(not_1.not(strings_1.startsWith('^')), strings_1.prepend('^')), given_1.given(not_1.not(strings_1.endsWith('*')), strings_1.append('$')))(moduleName);
    config[transformedModuleName] = modulePath;
    return config;
};
/**
 * Transforms the wildcard tokens ("*") to a RegExp groups (.*),
 * accounting for their reference in the alias strings.
 */
var transformWildcards = function (config, _a) {
    var moduleName = _a[0], modulePath = _a[1];
    var transformedModuleName = strings_1.replace(/\*/g, function () { return '(.*)'; })(moduleName);
    var transformedModulePath = Array.isArray(modulePath)
        ? modulePath.map(strings_1.replaceWildcardWithPositionals)
        : strings_1.replaceWildcardWithPositionals(modulePath);
    config[transformedModuleName] = transformedModulePath;
    return config;
};
/**
 * Generates a partial Jest configuration to enable given alias.
 * @see https://jestjs.io/docs/configuration
 */
function toJestConfig(config) {
    var moduleNameMapper = compose_1.compose(objects_1.reduceEntries(normalizeExactMatch), objects_1.reduceEntries(transformWildcards))(config);
    return {
        moduleNameMapper: moduleNameMapper
    };
}
exports.toJestConfig = toJestConfig;
